@@ -13,6 +13,7 @@ from .event import (
     CameraMotionEvent,
     CameraPersonEvent,
     CameraSoundEvent,
+    EventImageType,
     EventTrait,
     ImageEventBase,
 )
@@ -270,13 +271,6 @@ class CameraLiveStreamTrait:
         return WebRtcStream(results, self._cmd)
 
 
-class EventImageType(Enum):
-    """Event image type."""
-
-    IMAGE = 1, "An image generated from the event."
-    CLIP_PREVIEW = 2, "A 10 frame video file in mp4 format."
-
-
 class EventImage:
     """Provides access to an image in response to an event.
 
@@ -394,6 +388,11 @@ class CameraEventImageTrait:
 class EventImageGenerator(EventTrait, ABC):
     """Parenet class for a trait that generates an images from events."""
 
+    @property
+    @abstractmethod
+    def event_type(self) -> str:
+        """Event types supported by this trait."""
+
     async def generate_event_image(self, event: ImageEventBase) -> Optional[EventImage]:
         """Provide a URL to download a camera image from the active event."""
 
@@ -426,6 +425,7 @@ class CameraMotionTrait(EventImageGenerator):
 
     NAME = "sdm.devices.traits.CameraMotion"
     EVENT_NAME = CameraMotionEvent.NAME
+    event_type = EVENT_NAME
 
     def __init__(self, data: Mapping[str, Any], cmd: Command):
         """Initialize CameraClipPreviewTrait."""
@@ -446,6 +446,7 @@ class CameraPersonTrait(EventImageGenerator):
 
     NAME = "sdm.devices.traits.CameraPerson"
     EVENT_NAME = CameraPersonEvent.NAME
+    event_type = EVENT_NAME
 
     def __init__(self, data: Mapping[str, Any], cmd: Command):
         """Initialize CameraClipPreviewTrait."""
@@ -466,6 +467,7 @@ class CameraSoundTrait(EventImageGenerator):
 
     NAME = "sdm.devices.traits.CameraSound"
     EVENT_NAME = CameraSoundEvent.NAME
+    event_type = EVENT_NAME
 
     def __init__(self, data: Mapping[str, Any], cmd: Command):
         """Initialize CameraClipPreviewTrait."""
@@ -486,6 +488,7 @@ class CameraClipPreviewTrait(EventImageGenerator):
 
     NAME = "sdm.devices.traits.CameraClipPreview"
     EVENT_NAME = CameraClipPreviewEvent.NAME
+    event_type = EVENT_NAME
 
     def __init__(self, data: Mapping[str, Any], cmd: Command):
         """Initialize CameraClipPreviewTrait."""
