@@ -22,7 +22,7 @@ import json
 import logging
 import os
 import pickle
-from typing import Optional, List, cast
+from typing import List, Optional, cast
 
 import yaml
 from aiohttp import ClientSession
@@ -31,12 +31,12 @@ from google.auth.transport.requests import Request
 from google_auth_oauthlib.flow import InstalledAppFlow
 
 from .auth import AbstractAuth
-from .structure import Structure
-from .device import Device
 from .camera_traits import CameraLiveStreamTrait
+from .device import Device
 from .event import EventMessage
 from .google_nest_api import GoogleNestAPI
 from .google_nest_subscriber import GoogleNestSubscriber
+from .structure import Structure
 from .thermostat_traits import (
     ThermostatEcoTrait,
     ThermostatModeTrait,
@@ -108,6 +108,9 @@ set_range_parser.add_argument(
 )
 generate_rtsp_stream_parser = cmd_parser.add_parser("generate_rtsp_stream")
 generate_rtsp_stream_parser.add_argument("device_id")
+generate_web_rtc_stream_parser = cmd_parser.add_parser("generate_web_rtc_stream")
+generate_web_rtc_stream_parser.add_argument("device_id")
+generate_web_rtc_stream_parser.add_argument("offer_file")
 subscribe_parser = cmd_parser.add_parser("subscribe")
 subscribe_parser.add_argument("subscription_id")
 subscribe_parser.add_argument("device_id", nargs="?")
@@ -315,6 +318,17 @@ async def RunTool(args: argparse.Namespace, user_creds: Credentials) -> None:
             print(f"Stream Token: {stream.stream_token}")
             print(f"Expires At: {stream.expires_at}")
 
+        if args.command == "generate_web_rtc_stream":
+            trait = device.traits[CameraLiveStreamTrait.NAME]
+            offer_sdp = None
+            if args.offer_file:
+                f = open(args.offer_file, "r")
+                offer_sdp = f.read()
+            stream = await trait.generate_web_rtc_stream(offer_sdp)
+            print(f"Answer SDP: {stream.answer_sdp}")
+            print(f"Media Session Id: {stream.media_session_id}")
+            print(f"Expires At: {stream.expires_at}")
+
 
 def main() -> None:
     """Nest command line tool."""
